==> clean_android_design-0.2.15.tar.gz: lib/src/router/navigator_widgets/router_navigator_scaffold.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:clean_android_design/src/router/navigator_widgets/dialog_navigator_widget.dart';
import 'package:clean_android_design/src/router/navigator_widgets/multiple_navigator_widget.dart';
import 'package:clean_android_design/src/router/navigator_widgets/single_navigator_widget.dart';
import 'package:flutter/material.dart';

class RouterNavigatorScaffold extends StatefulWidget {
  RouterNavigatorScaffold({
    Key? key,
    required this.navigatorKey,
    required this.routePath,
    required this.notifyListeners,
    required this.pageCollectionMap,
    required this.sideMenuWidgetBuilder,
  }) : super(key: key);

  final GlobalKey<NavigatorState> navigatorKey;
  final SplitRoutePath routePath;
  final void Function() notifyListeners;
  final PageCollectionMap pageCollectionMap;

  final Widget Function(BuildContext context, SplitRoutePath path)
      sideMenuWidgetBuilder;

  @override
  State<RouterNavigatorScaffold> createState() =>
      _RouterNavigatorScaffoldState();
}

class _RouterNavigatorScaffoldState extends State<RouterNavigatorScaffold> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Stack(
        children: [
          SplitRouterDelegate.instance.useOnlySingleNavigator
              ? SingleNavigatorWidget(
                  key: Key("SingleNavigatorWidget"),
                  navigatorKey: widget.navigatorKey,
                  routePath: widget.routePath,
                  notifyListeners: widget.notifyListeners,
                  pageCollectionMap: widget.pageCollectionMap,
                )
              : MultipleNavigatorWidget(
                  key: Key("MultipleNavigatorWidget"),
                  navigatorKey: widget.navigatorKey,
                  routePath: widget.routePath,
                  notifyListeners: widget.notifyListeners,
                  sideMenuWidgetBuilder: widget.sideMenuWidgetBuilder,
                ),
          // If wanted: DraggableNavigator
          DialogNavigatorWidget(
            routePath: widget.routePath,
            notifyListeners: widget.notifyListeners,
          ),
          LoadingWidget(),
        ],
      ),
    );
  }
}

==> clean_android_design-0.2.19.tar.gz: lib/src/router/navigator_widgets/router_navigator_scaffold.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:clean_android_design/src/router/navigator_widgets/dialog_navigator_widget.dart';
import 'package:clean_android_design/src/router/navigator_widgets/multiple_navigator_widget.dart';
import 'package:clean_android_design/src/router/navigator_widgets/single_navigator_widget.dart';
import 'package:flutter/material.dart';

class RouterNavigatorScaffold extends StatefulWidget {
  RouterNavigatorScaffold({
    Key? key,
    required this.navigatorKeyLeft,
    required this.navigatorKeyRight,
    required this.navigatorKeyDialog,
    required this.routePath,
    required this.notifyListeners,
    required this.pageCollectionMap,
    required this.sideMenuWidgetBuilder,
  }) : super(key: key);

  final GlobalKey<NavigatorState> navigatorKeyLeft;
  final GlobalKey<NavigatorState> navigatorKeyRight;
  final GlobalKey<NavigatorState> navigatorKeyDialog;
  final SplitRoutePath routePath;
  final void Function() notifyListeners;
  final PageCollectionMap pageCollectionMap;

  final Widget Function(BuildContext context, SplitRoutePath path)
      sideMenuWidgetBuilder;

  @override
  State<RouterNavigatorScaffold> createState() =>
      _RouterNavigatorScaffoldState();
}

class _RouterNavigatorScaffoldState extends State<RouterNavigatorScaffold> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Stack(
        children: [
          SplitRouterDelegate.instance.useOnlySingleNavigator
              ? SingleNavigatorWidget(
                  key: Key("SingleNavigatorWidget"),
                  navigatorKey: widget.navigatorKeyLeft,
                  routePath: widget.routePath,
                  notifyListeners: widget.notifyListeners,
                  pageCollectionMap: widget.pageCollectionMap,
                )
              : MultipleNavigatorWidget(
                  key: Key("MultipleNavigatorWidget"),
                  navigatorKeyLeft: widget.navigatorKeyLeft,
                  navigatorKeyRight: widget.navigatorKeyRight,
                  routePath: widget.routePath,
                  notifyListeners: widget.notifyListeners,
                  sideMenuWidgetBuilder: widget.sideMenuWidgetBuilder,
                ),
          // If wanted: DraggableNavigator
          DialogNavigatorWidget(
            navigatorKey: widget.navigatorKeyDialog,
            routePath: widget.routePath,
            notifyListeners: widget.notifyListeners,
          ),
          LoadingWidget(),
        ],
      ),
    );
  }
}
